@@ -135,11 +135,24 @@ struct _FlatpakTransactionClass
   gboolean (*webflow_start) (FlatpakTransaction *transaction,
                              const char         *remote,
                              const char         *url,
+                             GVariant           *options,
                              guint               id);
   void (*webflow_done) (FlatpakTransaction *transaction,
+                        GVariant           *options,
                         guint               id);
 
-  gpointer padding[6];
+  gboolean (*basic_auth_start) (FlatpakTransaction *transaction,
+                                const char         *remote,
+                                const char         *realm,
+                                GVariant           *options,
+                                guint               id);
+  void (*install_authenticator)   (FlatpakTransaction *transaction,
+                                   const char         *remote,
+                                   const char         *authenticator_ref);
+
+  gboolean (*ready_pre_auth) (FlatpakTransaction *transaction);
+
+  gpointer padding[3];
 };
 
 FLATPAK_EXTERN
@@ -149,7 +162,7 @@ FlatpakTransaction *flatpak_transaction_new_for_installation (FlatpakInstallatio
 
 FLATPAK_EXTERN
 void        flatpak_transaction_progress_set_update_frequency (FlatpakTransactionProgress *self,
-                                                               guint                       update_frequency);
+                                                               guint                       update_interval);
 FLATPAK_EXTERN
 char *      flatpak_transaction_progress_get_status (FlatpakTransactionProgress *self);
 FLATPAK_EXTERN
@@ -167,6 +180,10 @@ FlatpakTransactionOperationType flatpak_transaction_operation_get_operation_type
 FLATPAK_EXTERN
 const char *                    flatpak_transaction_operation_get_ref (FlatpakTransactionOperation *self);
 FLATPAK_EXTERN
+GPtrArray *                     flatpak_transaction_operation_get_related_to_ops (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
+gboolean                        flatpak_transaction_operation_get_is_skipped (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
 const char *                    flatpak_transaction_operation_get_remote (FlatpakTransactionOperation *self);
 FLATPAK_EXTERN
 GFile *                         flatpak_transaction_operation_get_bundle_path (FlatpakTransactionOperation *self);
@@ -181,6 +198,10 @@ GKeyFile *                      flatpak_transaction_operation_get_metadata (Flat
 FLATPAK_EXTERN
 GKeyFile *                      flatpak_transaction_operation_get_old_metadata (FlatpakTransactionOperation *self);
 FLATPAK_EXTERN
+const char * const *            flatpak_transaction_operation_get_subpaths (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
+gboolean                        flatpak_transaction_operation_get_requires_authentication (FlatpakTransactionOperation *self);
+FLATPAK_EXTERN
 const char *                    flatpak_transaction_operation_type_to_string (FlatpakTransactionOperationType kind);
 
 FLATPAK_EXTERN
@@ -206,9 +227,15 @@ FLATPAK_EXTERN
 void                flatpak_transaction_set_disable_related (FlatpakTransaction *self,
                                                              gboolean            disable_related);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_disable_auto_pin  (FlatpakTransaction *self,
+                                                               gboolean            disable_pin);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_reinstall (FlatpakTransaction *self,
                                                        gboolean            reinstall);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_no_interaction (FlatpakTransaction *self,
+                                                            gboolean            no_interaction);
+FLATPAK_EXTERN
 void                flatpak_transaction_set_force_uninstall (FlatpakTransaction *self,
                                                              gboolean            force_uninstall);
 FLATPAK_EXTERN
@@ -220,9 +247,17 @@ void                flatpak_transaction_set_parent_window (FlatpakTransaction *s
 FLATPAK_EXTERN
 const char *        flatpak_transaction_get_parent_window (FlatpakTransaction *self);
 FLATPAK_EXTERN
+void                flatpak_transaction_set_include_unused_uninstall_ops (FlatpakTransaction *self,
+                                                                          gboolean            include_unused_uninstall_ops);
+FLATPAK_EXTERN
+gboolean            flatpak_transaction_get_include_unused_uninstall_ops (FlatpakTransaction *self);
+FLATPAK_EXTERN
 void                flatpak_transaction_add_dependency_source (FlatpakTransaction  *self,
                                                                FlatpakInstallation *installation);
 FLATPAK_EXTERN
+void                flatpak_transaction_add_sideload_repo (FlatpakTransaction  *self,
+                                                           const char          *path);
+FLATPAK_EXTERN
 void                flatpak_transaction_add_default_dependency_sources (FlatpakTransaction *self);
 FLATPAK_EXTERN
 gboolean            flatpak_transaction_run (FlatpakTransaction *transaction,
@@ -238,6 +273,12 @@ GList *flatpak_transaction_get_operations (FlatpakTransaction *self);
 FLATPAK_EXTERN
 void               flatpak_transaction_abort_webflow (FlatpakTransaction *self,
                                                       guint               id);
+FLATPAK_EXTERN
+void               flatpak_transaction_complete_basic_auth (FlatpakTransaction *self,
+                                                            guint id,
+                                                            const char *user,
+                                                            const char *password,
+                                                            GVariant *options);
 
 FLATPAK_EXTERN
 gboolean            flatpak_transaction_add_install (FlatpakTransaction *self,
